@@ -1,21 +1,18 @@
-"""Django Imports"""
+# Django Imports
 from django.contrib.auth import get_user_model
 
-
-"""Rest Framework Imports"""
+# Rest Framework Imports
 from rest_framework import serializers
 from rest_framework_simplejwt.serializers import TokenObtainPairSerializer
 
-
-"""Third Party Imports"""
+# Third Party Imports
 from rest_api_payload import success_response
 
-
-"""Custom app -> Rest Auth Imports"""
+# Rest routes Imports
 from rest_routes.otp_verifications import OTPVerification
 
 
-"""Class Instantiations"""
+# Class Instantiations
 otp_verify = OTPVerification()
 User = get_user_model()
 
@@ -104,12 +101,32 @@ class ChangeUserPasswordSerializer(serializers.Serializer):
         required=True,
         style={"input_type": "password", "placeholder": "Repeat New Password"},
     )
-
+    
+    def validate_email(self, value):
+        
+        # Checks if user exists
+        user = User.objects.filter(email=value).exists()
+        
+        if not user:
+            raise serializers.ValidationError("Email address does not exist!")
+        
+        return value
+    
 
 class ResetPasswordOTPSerializer(serializers.Serializer):
     """Serializer to reset password using OTP"""
 
     email = serializers.EmailField(max_length=255, required=True)
+    
+    def validate_email(self, value):
+        
+        # Checks if user exists
+        user = User.objects.filter(email=value).exists()
+        
+        if not user:
+            raise serializers.ValidationError("Email address does not exist!")
+        
+        return value
 
 
 class CompleteResetPasswordOTPSerializer(serializers.Serializer):
@@ -128,6 +145,7 @@ class CompleteResetPasswordOTPSerializer(serializers.Serializer):
         required=True,
         style={"input_type": "password", "placeholder": "Confirm Password"},
     )
+    
 
 
 class OTPSerializer(serializers.Serializer):
@@ -135,16 +153,36 @@ class OTPSerializer(serializers.Serializer):
 
     email = serializers.EmailField(max_length=255, required=True)
     otp_code = serializers.CharField(required=True, max_length=6)
+    
+    def validate_email(self, value):
+        
+        # Checks if user exists
+        user = User.objects.filter(email=value).exists()
+        
+        if not user:
+            raise serializers.ValidationError("Email address does not exist!")
+        
+        return value
 
 
 class ResendOTPSerializer(serializers.Serializer):
     """Serializer to resend OTP code to user's email"""
 
     email = serializers.EmailField(max_length=255, required=True)
+    
+    def validate_email(self, value):
+        
+        # Checks if user exists
+        user = User.objects.filter(email=value).exists()
+        
+        if not user:
+            raise serializers.ValidationError("Email address does not exist!")
+        
+        return value
 
 
 class SuspendUserSerializer(serializers.Serializer):
     """Serializer to suspend a user"""
-
+    
     is_active = serializers.BooleanField(required=True)
     
