@@ -1,18 +1,18 @@
-"""Rest Framework Imports"""
+# Rest Framework Imports
 from rest_framework import status, views
 from rest_framework.permissions import IsAuthenticated, AllowAny
 from rest_framework.response import Response
 from rest_framework_simplejwt.views import TokenObtainPairView, TokenRefreshView
 from rest_framework_simplejwt.serializers import TokenRefreshSerializer
 
-from rest_routes.permissions import can_suspend_user_perm
+# DRF YASG Imports
+from drf_yasg.utils import swagger_auto_schema
 
-
-"""Third Party Imports"""
+# Third Party Imports
 from rest_api_payload import success_response, error_response
 
 
-"""Custom app -> Rest Auth Imports"""
+# Rest Auth Imports
 from rest_routes.utils import send_html_to_email
 from rest_routes.serializers import (
     CompleteResetPasswordOTPSerializer,
@@ -25,6 +25,7 @@ from rest_routes.serializers import (
     UserLoginObtainPairSerializer,
     UserSerializer,
 )
+from rest_routes.permissions import can_suspend_user_perm
 from rest_routes.otp_verifications import OTPVerification
 
 
@@ -75,6 +76,7 @@ class RegisterUser(views.APIView):
     serializer_class = RegisterUserSerializer
     permission_classes = [AllowAny]
 
+    @swagger_auto_schema(request_body=serializer_class)
     def post(self, request: HttpRequest) -> Response:
         """
         It creates a new user.
@@ -93,7 +95,7 @@ class RegisterUser(views.APIView):
                 message="An OTP code has been sent to your email address!",
                 data=serializer.data,
             )
-            return Response(data=payload, status=status.HTTP_200_OK)
+            return Response(data=payload, status=status.HTTP_201_CREATED)
 
         payload = error_response(status="failed", message=serializer.errors)
         return Response(data=payload, status=status.HTTP_400_BAD_REQUEST)
@@ -115,6 +117,7 @@ class ConfirmUserOTP(views.APIView):
     serializer_class = OTPSerializer
     permission_classes = [AllowAny]
 
+    @swagger_auto_schema(request_body=serializer_class)
     def post(self, request: HttpRequest) -> Response:
         serializer = self.serializer_class(data=request.data)
 
@@ -201,6 +204,7 @@ class ResendUserOTP(views.APIView):
             )
             return Response(data=payload, status=status.HTTP_400_BAD_REQUEST)
 
+    @swagger_auto_schema(request_body=serializer_class)
     def post(self, request: HttpRequest) -> Response:
         serializer = self.serializer_class(data=request.data)
 
@@ -213,7 +217,7 @@ class ResendUserOTP(views.APIView):
             user = self.get_user(email=otp_data.get("email"))
 
             """Check if a user active and email active flag is True"""
-            if user.is_active == True and user.is_email_active == True:
+            if user.is_active and user.is_email_active:
 
                 payload = success_response(
                     status="success", message="You are already verified!", data={}
@@ -249,82 +253,83 @@ class SuspendUser(views.APIView):
     permissions_classes = [IsAuthenticated]
     user_serializer = UserSerializer
     suspend_user_serializer = SuspendUserSerializer
-    
-    def get_single_user(self, email:str) -> Response:
-        
+
+    def get_single_user(self, email: str):
+
         try:
             user = User.objects.get(email=email)
             return user
         except User.DoesNotExist:
-            payload = error_response(
-                status="error",
-                message="User does not exist!"
-            )
-            return Response(data=payload, status=status.HTTP_400_BAD_REQUEST)
-        
-    def get(self, request:HttpRequest, email:str) -> Response:
+            return Response(data={}, status=status.HTTP_400_BAD_REQUEST)
+
+    def get(self, request: HttpRequest, email: str) -> Response:
         user = self.get_single_user(email=email)
-        serializer = self.user_serializer(user)
-        
-        payload = success_response(
-            status="success",
-            message="User retrieved!",
-            data=serializer.data
-        )
-        return Response(data=payload, status=status.HTTP_200_OK)
-    
-    def put(self, request:HttpRequest, email:str) -> Response:
+
+        if user.status_code == 400:
+            payload = error_response(status="error", message="User does not exist!")
+            return Response(data=payload, status=status.HTTP_200_OK)
+
+        else:
+            serializer = self.user_serializer(user)
+
+            payload = success_response(
+                status="success", message="User retrieved!", data=serializer.data
+            )
+            return Response(data=payload, status=status.HTTP_200_OK)
+
+    @swagger_auto_schema(request_body=suspend_user_serializer)
+    def put(self, request: HttpRequest, email: str) -> Response:
         user = self.get_single_user(email=email)
         serializer = self.suspend_user_serializer(user, data=request.data)
-        
+
         """
         Check if the serializer is valid and the user 
         making the request has permission to suspend a user
         """
-        if serializer.is_valid() == True and can_suspend_user_perm(request=request) == True:
-            
+        if (
+            serializer.is_valid() == True
+            and can_suspend_user_perm(request=request) == True
+        ):
+
             is_active = serializer.validated_data.get("is_active")
-            
+
             if is_active == False:
-                
+
                 user.is_active = False
                 user.save()
-            
+
                 payload = success_response(
                     status="success",
                     message="User has been suspended!",
                     data={
                         "user": self.user_serializer(user).data,
-                        "user_meta": serializer.data
-                    }
+                        "user_meta": serializer.data,
+                    },
                 )
                 return Response(data=payload, status=status.HTTP_202_ACCEPTED)
-            
+
             elif is_active == True:
-                
+
                 user.is_active = True
                 user.save()
-                
+
                 payload = success_response(
                     status="success",
                     message="User has been activated!",
-                    data=serializer.data
+                    data=serializer.data,
                 )
                 return Response(data=payload, status=status.HTTP_202_ACCEPTED)
-        
+
         elif can_suspend_user_perm(request=request) == False:
-            
+
             payload = error_response(
                 status="error",
-                message="You don't have the required permission to perform this action!"
+                message="You don't have the required permission to perform this action!",
             )
             return Response(data=payload, status=status.HTTP_400_BAD_REQUEST)
-          
-        else:  
-            payload = error_response(
-                status="error",
-                message=serializer.errors
-            )
+
+        else:
+            payload = error_response(status="error", message=serializer.errors)
             return Response(data=payload, status=status.HTTP_400_BAD_REQUEST)
 
 
@@ -345,15 +350,14 @@ class ChangeUserPassword(views.APIView):
             user = User.objects.get(is_active=True, email=email)
             return user
         except User.DoesNotExist:
-            payload = error_response(
-                status="failed", message="Credentials does not match our record!"
-            )
-            return Response(data=payload, status=status.HTTP_404_NOT_FOUND)
+            return Response(data={}, status=status.HTTP_404_NOT_FOUND)
 
+    @swagger_auto_schema(request_body=serializer_class)
     def put(self, request: HttpRequest, email: str) -> Response:
 
         """Get current logged in user"""
         user = self.get_current_user(email=email)
+
         serializer = self.serializer_class(user, data=request.data)
 
         if serializer.is_valid():
@@ -406,10 +410,11 @@ class ChangeUserPassword(views.APIView):
         return Response(data=payload, status=status.HTTP_400_BAD_REQUEST)
 
 
-class ResetUserPasswordOTPAPIView(views.APIView):
+class ResetUserPasswordOTP(views.APIView):
     permission_classes = [AllowAny]
     serializer_class = ResetPasswordOTPSerializer
 
+    @swagger_auto_schema(request_body=serializer_class)
     def post(self, request: HttpRequest) -> Response:
         serializer = self.serializer_class(data=request.data)
 
@@ -440,10 +445,11 @@ class ResetUserPasswordOTPAPIView(views.APIView):
             return Response(data=payload, status=status.HTTP_400_BAD_REQUEST)
 
 
-class ConfirmResetUserPasswordOTPAPIView(views.APIView):
+class ConfirmResetUserPasswordOTP(views.APIView):
     permission_classes = [AllowAny]
     serializer_class = OTPSerializer
 
+    @swagger_auto_schema(request_body=serializer_class)
     def post(self, request: HttpRequest) -> Response:
         serializer = self.serializer_class(data=request.data)
 
@@ -492,10 +498,11 @@ class ConfirmResetUserPasswordOTPAPIView(views.APIView):
                 return Response(data=payload, status=status.HTTP_400_BAD_REQUEST)
 
 
-class ResetUserPasswordOTPCompleteAPIView(views.APIView):
+class ResetUserPasswordOTPComplete(views.APIView):
     permission_classes = [AllowAny]
     serializer_class = CompleteResetPasswordOTPSerializer
 
+    @swagger_auto_schema(request_body=serializer_class)
     def post(self, request: HttpRequest) -> Response:
         serializer = self.serializer_class(data=request.data)
 
@@ -549,13 +556,8 @@ class LogUserOut(views.APIView):
     session data.
     """
 
-    response = Response()
-
     def post(self, request: HttpRequest) -> Response:
 
-        """Flush out user's session from the client side"""
-        request.session.flush()
-
         """Wipes user request"""
         logout(request)
 
